==> haskell-interpolatedstring-perl6-1.0.0-79-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.0
id: interpolatedstring-perl6-1.0.0-7qm1nKrZaeXLmRarfcCNOU
key: interpolatedstring-perl6-1.0.0-7qm1nKrZaeXLmRarfcCNOU
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 8c6efea56526c7a17a5c3350a582a064
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.4.3/site-local/interpolatedstring-perl6-1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/interpolatedstring-perl6-1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.0-7qm1nKrZaeXLmRarfcCNOU
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.0.3-CxBfmRqT01jLfpwXm4KU0I
    template-haskell-2.13.0.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             haskell-src-meta-0.8.0.3-CxBfmRqT01jLfpwXm4KU0I=f0d8e3117ecce07c9354fb2d80f0abe7
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.0-81-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.0
id: interpolatedstring-perl6-1.0.0-4wV4POUkrKzH9hAmqzStFN
key: interpolatedstring-perl6-1.0.0-4wV4POUkrKzH9hAmqzStFN
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 7118422cc97e1a054824db611dc929b4
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.4.3/site-local/interpolatedstring-perl6-1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/interpolatedstring-perl6-1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.0-4wV4POUkrKzH9hAmqzStFN
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.0.3-61XnM4WleDeGLk27yiphHB
    template-haskell-2.13.0.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             haskell-src-meta-0.8.0.3-61XnM4WleDeGLk27yiphHB=65f1df1f23bf98020ed6aed114debf62
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
